@@ -7,14 +7,12 @@ from allauth.socialaccount.providers.oauth2.views import (
     OAuth2LoginView,
 )
 
-from .provider import MailRuProvider
-
 
 class MailRuOAuth2Adapter(OAuth2Adapter):
-    provider_id = MailRuProvider.id
-    access_token_url = "https://connect.mail.ru/oauth/token"
+    provider_id = "mailru"
+    access_token_url = "https://connect.mail.ru/oauth/token"  # nosec
     authorize_url = "https://connect.mail.ru/oauth/authorize"
-    profile_url = "http://www.appsmail.ru/platform/api"
+    profile_url = "https://www.appsmail.ru/platform/api"
 
     def complete_login(self, request, app, token, **kwargs):
         uid = kwargs["response"]["x_mailru_vid"]
@@ -25,9 +23,10 @@ class MailRuOAuth2Adapter(OAuth2Adapter):
             "uids": uid,
         }
         param_list = sorted([item + "=" + data[item] for item in data])
+        # See: https://api.mail.ru/docs/guides/restapi/
         data["sig"] = md5(
             ("".join(param_list) + app.secret).encode("utf-8")
-        ).hexdigest()
+        ).hexdigest()  # nosec
         response = (
             get_adapter().get_requests_session().get(self.profile_url, params=data)
         )
